@@ -114,6 +114,7 @@ tracker_seccomp_init (void)
 	ALLOW_RULE (rt_sigprocmask);
 	ALLOW_RULE (sched_yield);
 	ALLOW_RULE (sched_getaffinity);
+	ERROR_RULE (sched_setattr, EPERM);
 	ALLOW_RULE (nanosleep);
 	ALLOW_RULE (waitid);
 	ALLOW_RULE (waitpid);
@@ -138,7 +139,6 @@ tracker_seccomp_init (void)
 	/* Descriptors */
 	ALLOW_RULE (close);
 	ALLOW_RULE (read);
-	ALLOW_RULE (pread64);
 	ALLOW_RULE (lseek);
 	ALLOW_RULE (_llseek);
 	ALLOW_RULE (fadvise64);
@@ -209,6 +209,14 @@ tracker_seccomp_init (void)
 	                      SCMP_CMP(2, SCMP_CMP_MASKED_EQ, O_RDWR, O_RDWR)) < 0)
 		goto out;
 
+	/* Syscalls may differ between libcs */
+#if !defined(__GLIBC__)
+	ALLOW_RULE (rt_sigreturn);
+	ALLOW_RULE (readv);
+#else
+	ALLOW_RULE (pread64);
+#endif
+
 	g_debug ("Loading seccomp rules.");
 
 	if (seccomp_load (ctx) >= 0) {
